@@ -305,6 +305,7 @@ class SettingsManager {
         }
 
         const general = this.settings.general;
+        const planner = general.initial_planner || 'none';
         return `
             <div class="general-settings">
                 <div class="form-group">
@@ -322,6 +323,18 @@ class SettingsManager {
                         <option value="consensus" ${general.default_mode === 'consensus' ? 'selected' : ''}>Consensus</option>
                     </select>
                 </div>
+                <div class="form-group">
+                    <label>Initial Planner Agent</label>
+                    <select id="general-planner">
+                        <option value="none" ${planner === 'none' ? 'selected' : ''}>None (Chaotic Collaboration)</option>
+                        <option value="openai" ${planner === 'openai' ? 'selected' : ''}>🟢 OpenAI</option>
+                        <option value="anthropic" ${planner === 'anthropic' ? 'selected' : ''}>🔵 Anthropic</option>
+                        <option value="gemini" ${planner === 'gemini' ? 'selected' : ''}>🟡 Gemini</option>
+                    </select>
+                    <small style="color: var(--text-secondary); display: block; margin-top: 0.5rem;">
+                        When set, this agent will create the initial plan/design, then other agents will improve and build on it.
+                    </small>
+                </div>
                 <div class="form-group">
                     <label>Log Level</label>
                     <select id="general-log-level">
@@ -399,6 +412,7 @@ class SettingsManager {
             theme: document.getElementById('general-theme')?.value || 'dark',
             default_mode: document.getElementById('general-mode')?.value || 'tri',
             log_level: document.getElementById('general-log-level')?.value || 'info',
+            initial_planner: document.getElementById('general-planner')?.value || 'none',
             auto_save: this.settings.general.auto_save
         };
 
