@@ -6,6 +6,8 @@ Provides a Claude-style web interface with real-time agent visualization.
 
 import asyncio
 import json
+import os
+from pathlib import Path
 from typing import Optional, Dict, Any, List
 from datetime import datetime
 
@@ -19,6 +21,30 @@ from .orchestrator import AiTril
 from .coordinator import CoordinationStrategy
 from .settings import Settings
 
+# Load environment variables from .env file if it exists
+try:
+    from dotenv import load_dotenv
+    import logging
+    logger = logging.getLogger("uvicorn")
+
+    # Try to load from project root directory
+    project_root = Path(__file__).parent.parent
+    env_file = project_root / ".env"
+    if env_file.exists():
+        load_dotenv(env_file, override=True)
+        logger.info(f"✓ Loaded environment variables from {env_file}")
+        # Verify API keys loaded
+        api_keys = {
+            "OPENAI": "SET" if os.environ.get("OPENAI_API_KEY") else "NOT SET",
+            "ANTHROPIC": "SET" if os.environ.get("ANTHROPIC_API_KEY") else "NOT SET",
+            "GOOGLE": "SET" if os.environ.get("GOOGLE_API_KEY") else "NOT SET"
+        }
+        logger.info(f"API Keys status: {api_keys}")
+    else:
+        logger.warning(f".env file not found at {env_file}")
+except ImportError:
+    pass  # dotenv not installed, skip
+
 
 class ChatMessage(BaseModel):
     """Chat message from user."""
@@ -80,6 +106,7 @@ async def get_index():
         <meta charset="UTF-8">
         <meta name="viewport" content="width=device-width, initial-scale=1.0">
         <title>AiTril - Multi-Agent Orchestration</title>
+        <link rel="icon" href="data:image/svg+xml,<svg xmlns=%22http://www.w3.org/2000/svg%22 viewBox=%220 0 100 100%22><text y=%22.9em%22 font-size=%2290%22>🧬</text></svg>">
         <link rel="stylesheet" href="/static/style.css">
     </head>
     <body>
@@ -92,6 +119,14 @@ async def get_index():
     return HTMLResponse(content=html_content)
 
 
+@app.get("/favicon.ico")
+async def get_favicon():
+    """Serve favicon as SVG emoji."""
+    from fastapi.responses import Response
+    svg_content = """<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 100 100"><text y=".9em" font-size="90">🧬</text></svg>"""
+    return Response(content=svg_content, media_type="image/svg+xml")
+
+
 @app.websocket("/ws")
 async def websocket_endpoint(websocket: WebSocket):
     """WebSocket endpoint for real-time chat and agent updates."""
@@ -144,11 +179,15 @@ async def websocket_endpoint(websocket: WebSocket):
             # Create AiTril instance
             aitril = AiTril(config, session_name=session, use_cache=True)
 
+            # Get initial planner setting
+            general_settings = settings_manager.get_general_settings()
+            initial_planner = general_settings.get("initial_planner", "none")
+
             # Execute based on mode
             if mode == "ask" and provider:
                 await handle_ask(websocket, aitril, prompt, provider)
             elif mode == "tri":
-                await handle_tri(websocket, aitril, prompt)
+                await handle_tri(websocket, aitril, prompt, initial_planner)
             elif mode in ["sequential", "consensus", "debate"]:
                 await handle_coordination(websocket, aitril, prompt, mode)
             elif mode == "build":
@@ -187,27 +226,68 @@ async def handle_ask(websocket: WebSocket, aitril: AiTril, prompt: str, provider
     })
 
 
-async def handle_tri(websocket: WebSocket, aitril: AiTril, prompt: str):
-    """Handle tri-lam mode with parallel agent visualization."""
+async def handle_tri(websocket: WebSocket, aitril: AiTril, prompt: str, initial_planner: str = "none"):
+    """Handle tri-lam mode with parallel agent visualization or planner-first mode."""
     providers = aitril.get_enabled_providers()
 
     # Send tri-lam started event
     await manager.send_event(websocket, {
         "type": "trilam_started",
         "providers": providers,
+        "planner": initial_planner,
         "timestamp": datetime.now().isoformat()
     })
 
-    # Create tasks for each provider
-    tasks = []
-    for provider in providers:
-        task = asyncio.create_task(
-            stream_provider_response(websocket, aitril, provider, prompt)
-        )
-        tasks.append(task)
+    # If using planner-first mode, use non-streaming orchestrator
+    if initial_planner != "none" and initial_planner in providers:
+        # Send planner started event
+        await manager.send_event(websocket, {
+            "type": "agent_started",
+            "agent": initial_planner,
+            "role": "planner",
+            "timestamp": datetime.now().isoformat()
+        })
 
-    # Wait for all tasks to complete
-    await asyncio.gather(*tasks)
+        # Get responses using planner-first logic
+        responses = await aitril.ask_tri(prompt, initial_planner=initial_planner)
+
+        # Send planner response first
+        if initial_planner in responses:
+            await manager.send_event(websocket, {
+                "type": "agent_completed",
+                "agent": initial_planner,
+                "role": "planner",
+                "response": responses[initial_planner],
+                "timestamp": datetime.now().isoformat()
+            })
+
+        # Send other responses
+        for provider, response in responses.items():
+            if provider != initial_planner:
+                await manager.send_event(websocket, {
+                    "type": "agent_started",
+                    "agent": provider,
+                    "role": "builder",
+                    "timestamp": datetime.now().isoformat()
+                })
+                await manager.send_event(websocket, {
+                    "type": "agent_completed",
+                    "agent": provider,
+                    "role": "builder",
+                    "response": response,
+                    "timestamp": datetime.now().isoformat()
+                })
+    else:
+        # Use parallel streaming mode (original behavior)
+        tasks = []
+        for provider in providers:
+            task = asyncio.create_task(
+                stream_provider_response(websocket, aitril, provider, prompt)
+            )
+            tasks.append(task)
+
+        # Wait for all tasks to complete
+        await asyncio.gather(*tasks)
 
     # Send completion event
     await manager.send_event(websocket, {
@@ -598,4 +678,4 @@ async def health_check():
 
 if __name__ == "__main__":
     import uvicorn
-    uvicorn.run(app, host="0.0.0.0", port=8000)
+    uvicorn.run(app, host="0.0.0.0", port=37142)
